using System;
using System.Collections.Generic;
using Jypeli;
using Jypeli.Assets;
using Jypeli.Controls;
using Jypeli.Effects;
using Jypeli.Widgets;

namespace SierpinskiMatto;
/// @author  Vesa Lappalainen
/// @version 06.11.2011
/// <summary>
///  Sierpinskin matto. Ks. 
/// http://en.wikipedia.org/wiki/Sierpinski_carpet
/// http://commons.wikimedia.org/wiki/File:Sierpinski_carpet_4.svg 
/// </summary>
public class SierpinskiMatto : Game
{
    double pieninNelio = 1;

    /// <summary>
    /// Kutsutaan aliohjelmaa.
    /// </summary>
    public override void Begin()
    {
        SierpinskiCarpet(0, 0, 200);
    }

    /// <summary>
    /// Piirretään Sierpinskin matto.
    /// </summary>
    /// <param name="x">Neliön x.</param>
    /// <param name="y">Neliön y.</param>
    /// <param name="koko">Neliön sivun mitta.</param>
    public void SierpinskiCarpet(double x, double y, double koko)
    {
        // Lopetusehto neliöiden piirtämiselle. Jos
        // neliön koko alittaa pienimmän sallitun, hypätään
        // aliohjelmasta pois.
        if (koko < pieninNelio) return;

        GameObject nelio = new GameObject(koko, koko);
        nelio.Position = new Vector(x, y);
        nelio.Color = Color.Black;
        Add(nelio);

        // Ylärivi
        SierpinskiCarpet(x - koko, y + koko, koko / 3);
        SierpinskiCarpet(x, y + koko, koko / 3);
        SierpinskiCarpet(x + koko, y + koko, koko / 3);

        // Keskirivi
        SierpinskiCarpet(x - koko, y, koko / 3);
        SierpinskiCarpet(x + koko, y, koko / 3);

        // Alarivi
        SierpinskiCarpet(x - koko, y - koko, koko / 3);
        SierpinskiCarpet(x, y - koko, koko / 3);
        SierpinskiCarpet(x + koko, y - koko, koko / 3);
    }

}
